"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useMenu = void 0;
var tslib_1 = require("tslib");
var react_1 = tslib_1.__importStar(require("react"));
var react_native_1 = require("react-native");
var Menu_types_1 = require("./Menu.types");
var menuContext_1 = require("../context/menuContext");
// Due to how events get fired we get double notifications
// for the same event causing us to immediately reopen
// a menu when we close it. Adding in a delay to prevent
// this behavior.
// This are use when show() function is called to show the Menu
var delayOpen = 150;
/**
 * Values related to Screen Width and Animation Easing
 */
//  Animated easing value for Menu transitions(close and open)
var EASING = react_native_1.Easing.bezier(0.4, 0, 0.2, 1);
// Screen indent is the fixed value according to Android guidelines which depicts the minimum distance from screen edge Menu should have
var SCREEN_INDENT = 16;
var useMenu = function (props) {
    /**
     * State , Ref and Context Values for Menu Container and Anchor
     */
    var triggerRef = react_1.default.useRef();
    var context = (0, menuContext_1.useMenuContext)();
    var isSubmenu = context.triggerRef !== null;
    var isOpenControlled = typeof props.open !== 'undefined';
    var _container = (0, react_1.useRef)(null);
    var _a = react_1.default.useState(Menu_types_1.AndroidMenuStates.Hidden), menuState = _a[0], setMenuState = _a[1];
    /**
     * Call for useMenuCheckedState for identifying if any MenuItemCheckbox is checked or not
     */
    var _b = useMenuCheckedState(props), checked = _b[0], onCheckedChange = _b[1];
    /**
     *  State Variables related to Height,Width and Position of the Menu Popover
     */
    var maxMenuHeight = (0, react_1.useState)(250)[0];
    var _c = react_1.default.useState(0), anchorWidth = _c[0], setAnchorWidth = _c[1];
    var _d = react_1.default.useState(0), left = _d[0], setLeft = _d[1];
    var _e = react_1.default.useState(0), menuHeight = _e[0], setMenuHeight = _e[1];
    var _f = react_1.default.useState(0), menuWidth = _f[0], setMenuWidth = _f[1];
    var _g = react_1.default.useState(0), top = _g[0], setTop = _g[1];
    /**
     *  Animation value for the Menu popover show,hide and opacity values
     */
    var _h = react_1.default.useState(new react_native_1.Animated.ValueXY({ x: 0, y: 0 })), menuSizeAnimation = _h[0], setMenuSizeAnimation = _h[1];
    var _j = react_1.default.useState(new react_native_1.Animated.Value(0)), opacityAnimation = _j[0], setOpacityAnimation = _j[1];
    /**
     * RTL for the MenuItem needs to taken care as well.
     */
    var isRTL = react_native_1.I18nManager.isRTL;
    /**
     * Calcualations related to Menu Popver position and dimensions
     */
    var dimensions = react_native_1.Dimensions.get('screen');
    var windowWidth = dimensions.width;
    var windowHeight = dimensions.height - (react_native_1.StatusBar.currentHeight || 0);
    var menuSize = {
        width: menuSizeAnimation.x,
        height: menuSizeAnimation.y,
    };
    /**
     * show function handles the opening of the Menu , it calcuates the position of the Anchor in the screen.
     * It also sets the Anchor width and change the state of the Popover
     */ /**
    * show function handles the opening of the Menu , it calcuates the position of the Anchor in the screen.
    * It also sets the Anchor width and change the state of the Popover
    */
    var show = react_1.default.useCallback(function () {
        var _a;
        (_a = _container.current) === null || _a === void 0 ? void 0 : _a.measureInWindow(function (left, top, buttonWidth, buttonHeight) {
            setAnchorWidth(buttonWidth);
            setLeft(left);
            setMenuState(Menu_types_1.AndroidMenuStates.Shown);
            setTop(top + buttonHeight);
        });
    }, []);
    /**
     * hide function handles the hiding of the Menu when user clicks on the scrim outside Menu or MenuItems such as (MenuItemRadio, MenuItem)
     */
    var hide = react_1.default.useCallback(function () {
        react_native_1.Animated.timing(opacityAnimation, {
            toValue: 0,
            duration: 250,
            easing: EASING,
            useNativeDriver: false,
        }).start(function () {
            // Reset state
            setMenuState(Menu_types_1.AndroidMenuStates.Hidden);
            setMenuSizeAnimation(new react_native_1.Animated.ValueXY({ x: 0, y: 0 }));
            setOpacityAnimation(new react_native_1.Animated.Value(0));
        });
    }, [opacityAnimation]);
    // Hook to maintain the state of the Menu for non controlled and controlled components.
    var _k = useMenuOpenState(isOpenControlled, props, context.setOpen, hide, show), open = _k[0], shouldFocusOnContainer = _k[1], setOpen = _k[2];
    /**
     * Checks the value of the open props and show the menu accordingly
     */
    (0, react_1.useEffect)(function () {
        if (props.open) {
            show();
        }
    }, [props.open]);
    /**
     * onMenuLayout handles the start of the Animation when anchor is clicked
     */
    var onMenuLayout = react_1.default.useCallback(function (e) {
        if (menuState === Menu_types_1.AndroidMenuStates.Animating) {
            return;
        }
        var _a = e.nativeEvent.layout, width = _a.width, height = _a.height;
        setMenuHeight(height);
        setMenuWidth(width);
        setMenuState(Menu_types_1.AndroidMenuStates.Animating);
        react_native_1.Animated.parallel([
            react_native_1.Animated.timing(menuSizeAnimation, {
                toValue: { x: width, y: height },
                duration: 100,
                easing: EASING,
                useNativeDriver: false,
            }),
            react_native_1.Animated.timing(opacityAnimation, {
                toValue: 1,
                duration: 100,
                easing: EASING,
                useNativeDriver: false,
            }),
        ]).start();
    }, [menuSizeAnimation, menuState, opacityAnimation]);
    /**
     * onRequestClose handles the closing of the Menu when the MenuItem or scrim or outside is clicked
     */
    var onRequestClose = function (e) {
        setOpen(e, false, false);
    };
    // Adjust position of menu
    var transforms = [];
    (0, react_1.useMemo)(function () {
        /**
         * If the Menu width and SCREEN_INDENT cross the screen width then the Menu will be adjusted to the oppostion left side of the screen
         */
        if ((isRTL && left + anchorWidth - menuWidth > SCREEN_INDENT) || (!isRTL && left + menuWidth > windowWidth - SCREEN_INDENT)) {
            transforms.push({
                translateX: react_native_1.Animated.multiply(menuSizeAnimation.x, -1),
            });
        }
        else if (left < SCREEN_INDENT) {
            // Setting the left podition of the Menu if the left positon is less than screen indent
            setLeft(SCREEN_INDENT);
        }
        // Flip by Y axis if menu hits bottom screen border
        if (top + menuHeight + SCREEN_INDENT > windowHeight) {
            if (menuHeight > maxMenuHeight) {
                transforms.push({
                    translateY: react_native_1.Animated.multiply(menuSizeAnimation.y, -1),
                });
            }
            else {
                transforms.push({
                    translateY: react_native_1.Animated.multiply(menuSizeAnimation.y, -1),
                });
            }
        }
        else if (top < SCREEN_INDENT) {
            setTop(SCREEN_INDENT);
        }
    }, [
        anchorWidth,
        isRTL,
        left,
        maxMenuHeight,
        menuHeight,
        menuSizeAnimation.x,
        menuSizeAnimation.y,
        menuWidth,
        top,
        transforms,
        windowHeight,
        windowWidth,
    ]);
    /**
     * Styles to be applied on the Modal Popover Animated.View
     */
    var shadowMenuContainerStyle = (0, react_1.useMemo)(function () {
        return tslib_1.__assign({ opacity: opacityAnimation, transform: transforms, top: top }, (isRTL ? { right: left } : { left: left }));
    }, [isRTL, left, opacityAnimation, top, transforms]);
    /**
     * handles the state when menu is opening or closing with Animation
     */
    var animationStarted = menuState === Menu_types_1.AndroidMenuStates.Animating;
    var testID = props.testID;
    // Default behavior for submenu is to open on hover
    // the ...props line below will override this behavior for a submenu
    // or apply openOnHover if passed into a root Menu.
    var openOnHover = isSubmenu;
    // We need to be able to cancel the timer that gets set on
    // hover out of the parent popover if the parent popover
    // is also set to open/close on hover out. Otherwise
    // the parent menu will close when the timeout passes.
    var parentPopoverHoverOutTimer = isSubmenu ? context.popoverHoverOutTimer : undefined;
    return tslib_1.__assign(tslib_1.__assign({ openOnHover: openOnHover }, props), { open: open, setOpen: setOpen, shouldFocusOnContainer: shouldFocusOnContainer, triggerRef: triggerRef, isSubmenu: isSubmenu, isControlled: isOpenControlled, parentPopoverHoverOutTimer: parentPopoverHoverOutTimer, setAnchorWidth: setAnchorWidth, shadowMenuContainerStyle: shadowMenuContainerStyle, _container: _container, onRequestClose: onRequestClose, onMenuLayout: onMenuLayout, checked: checked, onCheckedChange: onCheckedChange, menuHeight: menuHeight, maxMenuHeight: maxMenuHeight, animationStarted: animationStarted, menuSize: menuSize, testID: testID });
};
exports.useMenu = useMenu;
/**
 * useMenuOpenState handles the open and closing of the Menu based on the click
 * It also takes care of Controlled Menu component by checking open variable
 *
 */
var useMenuOpenState = function (isControlled, props, parentSetOpen, hide, show) {
    var defaultOpen = props.defaultOpen, onOpenChange = props.onOpenChange, open = props.open;
    var initialState = typeof defaultOpen !== 'undefined' ? defaultOpen : !!open;
    var _a = react_1.default.useState(initialState), openInternal = _a[0], setOpenInternal = _a[1];
    var _b = react_1.default.useState(undefined), shouldFocusOnContainer = _b[0], setShouldFocusOnContainer = _b[1];
    var state = isControlled ? open : openInternal;
    var lastCloseTimestampRef = react_1.default.useRef(-1);
    /**
     * setOpen handles the open of the Menu and setting focus on the Popover container
     */
    var setOpen = react_1.default.useCallback(function (e, isOpen, bubble) {
        var openPrev = state;
        if (!isControlled && (!isOpen || lastCloseTimestampRef.current + delayOpen <= Date.now())) {
            setOpenInternal(isOpen);
        }
        if (isOpen) {
            show();
            setShouldFocusOnContainer(true);
        }
        if (!isOpen) {
            setShouldFocusOnContainer(undefined);
            lastCloseTimestampRef.current = Date.now();
            hide();
        }
        if (onOpenChange && openPrev !== isOpen) {
            onOpenChange(e, isOpen);
        }
        if (bubble && parentSetOpen && !isControlled) {
            parentSetOpen(e, isOpen, bubble);
        }
    }, [state, onOpenChange, parentSetOpen, show, hide]);
    return [state, shouldFocusOnContainer, setOpen];
};
/**
 * Call for useMenuCheckedState for identifying if any MenuItemCheckbox is checked or not
 */
var useMenuCheckedState = function (props) {
    var _a;
    var checked = props.checked, defaultChecked = props.defaultChecked, onCheckedChangeOriginal = props.onCheckedChange;
    var _b = react_1.default.useState((_a = defaultChecked !== null && defaultChecked !== void 0 ? defaultChecked : checked) !== null && _a !== void 0 ? _a : []), checkedInternal = _b[0], setCheckedInternal = _b[1];
    var isControlled = typeof checked !== 'undefined';
    var state = isControlled ? checked : checkedInternal;
    var onCheckedChange = react_1.default.useCallback(function (e, checked) {
        if (!isControlled) {
            setCheckedInternal(checked);
        }
        onCheckedChangeOriginal === null || onCheckedChangeOriginal === void 0 ? void 0 : onCheckedChangeOriginal(e, checked);
    }, [isControlled, setCheckedInternal, onCheckedChangeOriginal]);
    return [state, onCheckedChange];
};
//# sourceMappingURL=useMenu.android.js.map