"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MenuGroup = void 0;
var tslib_1 = require("tslib");
/** @jsxRuntime classic */
/** @jsx withSlots */
var react_1 = tslib_1.__importDefault(require("react"));
var react_native_1 = require("react-native");
var focus_zone_1 = require("@fluentui-react-native/focus-zone");
var framework_1 = require("@fluentui-react-native/framework");
var MenuGroup_types_1 = require("./MenuGroup.types");
// Intentionally not enabled on macOS to match system context menus
var hasFocusZone = ['win32'].includes(react_native_1.Platform.OS);
exports.MenuGroup = (0, framework_1.compose)({
    displayName: MenuGroup_types_1.menuGroupName,
    slots: {
        root: react_native_1.View,
        contentWrapper: hasFocusZone ? focus_zone_1.FocusZone : react_1.default.Fragment,
    },
    useRender: function (userProps, useSlots) {
        var Slots = useSlots(userProps);
        return function (final, children) {
            var _a;
            var mergedProps = tslib_1.__rest((0, framework_1.mergeProps)(userProps, final), []);
            var itemPosition = 0;
            var childrenWithSet = react_1.default.Children.toArray(children).map(function (child) {
                var _a, _b;
                if (react_1.default.isValidElement(child)) {
                    var itemCount = react_1.default.Children.toArray(children).filter(function (child) {
                        return react_1.default.isValidElement(child) &&
                            child.type.displayName !== 'MenuGroupHeader' &&
                            child.type.displayName !== 'MenuDivider';
                    }).length;
                    if (child.type.displayName !== 'MenuGroupHeader' && child.type.displayName !== 'MenuDivider') {
                        itemPosition++;
                    }
                    return react_1.default.cloneElement(child, {
                        accessibilityPositionInSet: (_a = child.props.accessibilityPositionInSet) !== null && _a !== void 0 ? _a : itemPosition,
                        accessibilitySetSize: (_b = child.props.accessibilitySetSize) !== null && _b !== void 0 ? _b : itemCount, //win32
                    });
                }
                return child;
            });
            // Check if this MenuGroup has a MenuGroupHeader. If so, use the MenuGroupHeader
            // as the accessibilityLabel for the MenuGroup.
            var menuGroupHeader = react_1.default.Children.toArray(children).find(function (child) { return react_1.default.isValidElement(child) && child.type.displayName === 'MenuGroupHeader'; });
            // On win32, in order for assistive technology to read a group, it must have a name which is why
            // we use a string with a space as the default accessibilityLabel for MenuGroup.
            // If an empty string was used, the group context would not be read.
            var menuGroupA11yLabel = ' ';
            if (menuGroupHeader && typeof menuGroupHeader.props.children === 'string') {
                menuGroupA11yLabel = menuGroupHeader.props.children;
            }
            return ((0, framework_1.withSlots)(Slots.root, tslib_1.__assign({}, mergedProps, (react_native_1.Platform.OS == 'win32' && {
                accessible: true,
                accessibilityRole: 'group',
                accessibilityLabel: (_a = mergedProps.accessibilityLabel) !== null && _a !== void 0 ? _a : menuGroupA11yLabel,
            })),
                (0, framework_1.withSlots)(Slots.contentWrapper
                // avoid error that fires when props are passed into React.fragment
                , tslib_1.__assign({}, (hasFocusZone && {
                    focusZoneDirection: 'vertical',
                    enableFocusRing: false,
                    navigateAtEnd: 'NavigateContinue',
                })), childrenWithSet)));
        };
    },
});
//# sourceMappingURL=MenuGroup.js.map