"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTooltip = exports.getAccessibilityLabel = exports.MenuItem = void 0;
var tslib_1 = require("tslib");
var react_native_1 = require("react-native");
var framework_1 = require("@fluentui-react-native/framework");
var icon_1 = require("@fluentui-react-native/icon");
var text_1 = require("@fluentui-react-native/text");
var react_native_svg_1 = require("react-native-svg");
var MenuItem_styling_1 = require("./MenuItem.styling");
var MenuItem_types_1 = require("./MenuItem.types");
var useMenuItem_1 = require("./useMenuItem");
exports.MenuItem = (0, framework_1.compose)(tslib_1.__assign(tslib_1.__assign({ displayName: MenuItem_types_1.menuItemName }, MenuItem_styling_1.stylingSettings), { slots: {
        root: react_native_1.Pressable,
        checkmark: react_native_1.View,
        content: text_1.TextV1,
        iconPlaceholder: react_native_1.View,
        imgIcon: react_native_1.Image,
        fontOrSvgIcon: icon_1.IconV1,
        submenuIndicator: react_native_svg_1.SvgXml,
    }, useRender: function (userProps, useSlots) {
        var menuItem = (0, useMenuItem_1.useMenuItem)(userProps);
        var Slots = useSlots(userProps, function (layer) { return menuItem.state[layer] || userProps[layer]; });
        return function (final, children) {
            var _a = (0, framework_1.mergeProps)(menuItem.props, final), accessibilityLabel = _a.accessibilityLabel, icon = _a.icon, tooltip = _a.tooltip, mergedProps = tslib_1.__rest(_a, ["accessibilityLabel", "icon", "tooltip"]);
            var chevronXml = react_native_1.I18nManager.isRTL
                ? "\n          <svg>\n          <path fill='currentColor' d=\"M10.2603 3.20041C10.5639 3.48226 10.5814 3.95681 10.2996 4.26034L6.77348 8L10.2996 11.7397C10.5814 12.0432 10.5639 12.5177 10.2603 12.7996C9.9568 13.0815 9.48226 13.0639 9.2004 12.7603L5.2004 8.51034C4.9332 8.22258 4.9332 7.77743 5.2004 7.48966L9.20041 3.23966C9.48226 2.93613 9.95681 2.91856 10.2603 3.20041Z\"/>\n          </svg>"
                : "\n          <svg>\n          <path fill='currentColor' d=\"M5.73966 3.20041C5.43613 3.48226 5.41856 3.95681 5.70041 4.26034L9.22652 8L5.70041 11.7397C5.41856 12.0432 5.43613 12.5177 5.73967 12.7996C6.0432 13.0815 6.51775 13.0639 6.7996 12.7603L10.7996 8.51034C11.0668 8.22258 11.0668 7.77743 10.7996 7.48966L6.7996 3.23966C6.51775 2.93613 6.0432 2.91856 5.73966 3.20041Z\"/>\n          </svg>";
            // We only automatically support the one child string.
            var label = (0, exports.getAccessibilityLabel)(accessibilityLabel, children[0]);
            var tooltipResult = (0, exports.getTooltip)(tooltip, menuItem.state.hasTooltips, children[0]);
            return ((0, framework_1.withSlots)(Slots.root, tslib_1.__assign({}, mergedProps, { accessibilityLabel: label }),
                menuItem.state.hasCheckmarks && (0, framework_1.withSlots)(Slots.checkmark, { accessible: false }),
                (icon || menuItem.state.hasIcons) && ((0, framework_1.withSlots)(Slots.iconPlaceholder, { accessible: false },
                    icon && icon.source && (0, framework_1.withSlots)(Slots.imgIcon, tslib_1.__assign({ accessible: false }, icon)),
                    icon && (icon.svgSource || icon.fontSource) && (0, framework_1.withSlots)(Slots.fontOrSvgIcon, tslib_1.__assign({ accessible: false }, icon)))),
                children && ((0, framework_1.withSlots)(Slots.content, tslib_1.__assign({ accessible: false, tooltip: tooltipResult }, (tooltipResult && { alwaysShowToolTip: true })), children)),
                menuItem.state.hasSubmenu && (0, framework_1.withSlots)(Slots.submenuIndicator, { accessible: false, xml: chevronXml })));
        };
    } }));
var getAccessibilityLabelWorker = function (accessibilityLabel, child) {
    if (accessibilityLabel !== undefined) {
        return accessibilityLabel;
    }
    if (typeof child === 'string') {
        return child;
    }
    return undefined;
};
exports.getAccessibilityLabel = (0, framework_1.memoize)(getAccessibilityLabelWorker);
var getTooltipWorker = function (tooltip, hasTooltips, child) {
    if (tooltip !== undefined) {
        return tooltip;
    }
    if (hasTooltips && typeof child === 'string') {
        return child;
    }
    return undefined;
};
exports.getTooltip = (0, framework_1.memoize)(getTooltipWorker);
//# sourceMappingURL=MenuItem.js.map