"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useHoverFocusEffect = exports.useMenuItem = exports.submenuTriggerKeys = exports.triggerKeys = void 0;
var tslib_1 = require("tslib");
var React = tslib_1.__importStar(require("react"));
var react_native_1 = require("react-native");
var framework_1 = require("@fluentui-react-native/framework");
var interactive_hooks_1 = require("@fluentui-react-native/interactive-hooks");
var menuContext_1 = require("../context/menuContext");
var menuListContext_1 = require("../context/menuListContext");
var menuTriggerContext_1 = require("../context/menuTriggerContext");
var useMenuList_1 = require("../MenuList/useMenuList");
exports.triggerKeys = [' ', 'Enter'];
exports.submenuTriggerKeys = tslib_1.__spreadArray(['ArrowLeft', 'ArrowRight'], exports.triggerKeys, true);
var useMenuItem = function (props) {
    // attach the pressable state handlers
    var defaultComponentRef = React.useRef(null);
    var accessible = props.accessible, onClick = props.onClick, accessibilityState = props.accessibilityState, _a = props.componentRef, componentRef = _a === void 0 ? defaultComponentRef : _a, _b = props.disabled, disabled = _b === void 0 ? false : _b, persistOnClick = props.persistOnClick, rest = tslib_1.__rest(props, ["accessible", "onClick", "accessibilityState", "componentRef", "disabled", "persistOnClick"]);
    var _c = (0, menuContext_1.useMenuContext)(), isSubmenu = _c.isSubmenu, persistOnItemClick = _c.persistOnItemClick, setOpen = _c.setOpen;
    var _d = (0, menuListContext_1.useMenuListContext)(), hasCheckmarks = _d.hasCheckmarks, hasIcons = _d.hasIcons, hasTooltips = _d.hasTooltips, onArrowClose = _d.onArrowClose;
    var isTrigger = (0, menuTriggerContext_1.useMenuTriggerContext)();
    var shouldPersist = persistOnClick !== null && persistOnClick !== void 0 ? persistOnClick : persistOnItemClick;
    var hasSubmenu = isSubmenu && isTrigger;
    var onInvoke = React.useCallback(function (e) {
        var _a;
        var isRtl = react_native_1.I18nManager.isRTL;
        var isArrowKey = (0, interactive_hooks_1.isKeyPressEvent)(e) && (e.nativeEvent.key === 'ArrowLeft' || e.nativeEvent.key === 'ArrowRight');
        var isArrowOpen = hasSubmenu &&
            (0, interactive_hooks_1.isKeyPressEvent)(e) &&
            ((isRtl && e.nativeEvent.key === 'ArrowLeft') || (!isRtl && e.nativeEvent.key === 'ArrowRight'));
        if (!disabled && (!isArrowKey || isArrowOpen)) {
            (_a = componentRef === null || componentRef === void 0 ? void 0 : componentRef.current) === null || _a === void 0 ? void 0 : _a.blur();
            onClick === null || onClick === void 0 ? void 0 : onClick(e);
        }
        if (!hasSubmenu && !isArrowKey && !shouldPersist) {
            setOpen(e, false /*isOpen*/, true /*bubble*/);
        }
        var isArrowClose = (0, interactive_hooks_1.isKeyPressEvent)(e) && ((isRtl && e.nativeEvent.key === 'ArrowRight') || (!isRtl && e.nativeEvent.key === 'ArrowLeft'));
        if (isArrowClose) {
            onArrowClose === null || onArrowClose === void 0 ? void 0 : onArrowClose(e);
        }
    }, [componentRef, disabled, hasSubmenu, onArrowClose, onClick, setOpen, shouldPersist]);
    var pressable = (0, interactive_hooks_1.usePressableState)(tslib_1.__assign(tslib_1.__assign({}, rest), { onPress: onInvoke }));
    var itemRef = (0, interactive_hooks_1.useViewCommandFocus)(componentRef);
    var keys = disabled ? [] : isSubmenu ? exports.submenuTriggerKeys : exports.triggerKeys;
    // Explicitly override onKeyDown to override the native behavior of moving focus with arrow keys.
    var onKeyDownProps = interactive_hooks_1.useKeyDownProps.apply(void 0, tslib_1.__spreadArray([onInvoke], keys, false));
    (0, exports.useHoverFocusEffect)(pressable.state.hovered, componentRef);
    var _e = React.useState(!pressable.state.hovered), enableFocusRing = _e[0], setEnableFocusRing = _e[1];
    var onHoverIn = React.useCallback(function (e) {
        pressable.props.onHoverIn(e);
        // when it's a hover focus, set enableFocusRing explicitly to false
        if (!pressable.state.focused) {
            setEnableFocusRing(false);
        }
    }, [pressable]);
    var onFocus = React.useCallback(function (e) {
        pressable.props.onFocus(e);
        // when it's not a hover focus, set enableFocusRing explicitly to true
        if (!pressable.state.focused) {
            setEnableFocusRing(true);
        }
    }, [pressable]);
    // Track the ref and disabled props on this menu item so the MenuList can handle Home and End keypresses.
    (0, useMenuList_1.useMenuItemTracking)(componentRef, disabled);
    return {
        props: tslib_1.__assign(tslib_1.__assign(tslib_1.__assign({}, pressable.props), { onHoverIn: react_native_1.Platform.select({
                macos: pressable.props.onHoverIn,
                default: onHoverIn, // win32
            }), onFocus: react_native_1.Platform.select({
                macos: pressable.props.onFocus,
                default: onFocus, // win32
            }), accessible: accessible !== null && accessible !== void 0 ? accessible : true, accessibilityRole: 'menuitem', onAccessibilityTap: props.onAccessibilityTap || onInvoke, accessibilityState: getAccessibilityState(disabled, accessibilityState), disabled: disabled, enableFocusRing: react_native_1.Platform.select({
                macos: false,
                default: enableFocusRing, // win32
            }), focusable: react_native_1.Platform.select({
                macos: !disabled,
                default: true, // win32
            }), ref: itemRef }), onKeyDownProps),
        state: tslib_1.__assign(tslib_1.__assign({}, pressable.state), { hasSubmenu: hasSubmenu, hasIcons: hasIcons, hasCheckmarks: hasCheckmarks, hasTooltips: hasTooltips }),
    };
};
exports.useMenuItem = useMenuItem;
var getAccessibilityState = (0, framework_1.memoize)(getAccessibilityStateWorker);
function getAccessibilityStateWorker(disabled, accessibilityState) {
    if (accessibilityState) {
        return tslib_1.__assign({ disabled: disabled }, accessibilityState);
    }
    return { disabled: disabled };
}
var useHoverFocusEffect = function (hovered, componentRef) {
    React.useLayoutEffect(function () {
        var _a, _b;
        if (hovered) {
            (_a = componentRef === null || componentRef === void 0 ? void 0 : componentRef.current) === null || _a === void 0 ? void 0 : _a.focus();
        }
        else {
            (_b = componentRef === null || componentRef === void 0 ? void 0 : componentRef.current) === null || _b === void 0 ? void 0 : _b.blur();
        }
    }, [hovered, componentRef]);
};
exports.useHoverFocusEffect = useHoverFocusEffect;
//# sourceMappingURL=useMenuItem.js.map