"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useMenuCheckboxInteraction = exports.useMenuItemCheckbox = void 0;
var tslib_1 = require("tslib");
var React = tslib_1.__importStar(require("react"));
var react_native_1 = require("react-native");
var framework_1 = require("@fluentui-react-native/framework");
var interactive_hooks_1 = require("@fluentui-react-native/interactive-hooks");
var menuContext_1 = require("../context/menuContext");
var menuListContext_1 = require("../context/menuListContext");
var useMenuItem_1 = require("../MenuItem/useMenuItem");
var useMenuList_1 = require("../MenuList/useMenuList");
var defaultAccessibilityActions = [{ name: 'Toggle' }];
var useMenuItemCheckbox = function (props) {
    var _a;
    var _b = props.disabled, disabled = _b === void 0 ? false : _b, name = props.name;
    var context = (0, menuListContext_1.useMenuListContext)();
    var checked = (_a = context.checked) === null || _a === void 0 ? void 0 : _a[name];
    var onCheckedChange = context.onCheckedChange;
    var toggleChecked = React.useCallback(function (e) {
        if (!disabled) {
            onCheckedChange(e, name, !checked);
        }
    }, [checked, disabled, name, onCheckedChange]);
    return (0, exports.useMenuCheckboxInteraction)(props, toggleChecked);
};
exports.useMenuItemCheckbox = useMenuItemCheckbox;
var getAccessibilityState = (0, framework_1.memoize)(getAccessibilityStateWorker);
function getAccessibilityStateWorker(disabled, checked, accessibilityState) {
    if (accessibilityState) {
        return tslib_1.__assign({ disabled: disabled, checked: checked }, accessibilityState);
    }
    return { disabled: disabled, checked: checked };
}
/**
 * Create interactivity and accessibility props to be passed into the inner render.
 * This logic is shared between Checkbox and Radio versions of MenuItem.
 *
 * @param props Props passed into the outer compoennt
 * @param toggleCallback Function to be called when item is toggled
 * @returns Props and additional state needed to render the component
 */
var useMenuCheckboxInteraction = function (props, toggleCallback) {
    var defaultComponentRef = React.useRef(null);
    var accessibilityActions = props.accessibilityActions, accessibilityLabel = props.accessibilityLabel, accessibilityState = props.accessibilityState, accessible = props.accessible, _a = props.componentRef, componentRef = _a === void 0 ? defaultComponentRef : _a, _b = props.disabled, disabled = _b === void 0 ? false : _b, name = props.name, onAccessibilityAction = props.onAccessibilityAction, rest = tslib_1.__rest(props, ["accessibilityActions", "accessibilityLabel", "accessibilityState", "accessible", "componentRef", "disabled", "name", "onAccessibilityAction"]);
    var isSubmenu = (0, menuContext_1.useMenuContext)().isSubmenu;
    var _c = (0, menuListContext_1.useMenuListContext)(), checked = _c.checked, hasIcons = _c.hasIcons, hasTooltips = _c.hasTooltips, onArrowClose = _c.onArrowClose;
    var isChecked = checked === null || checked === void 0 ? void 0 : checked[name];
    // Ensure focus is placed on checkbox after click
    var toggleCheckedWithFocus = (0, interactive_hooks_1.useOnPressWithFocus)(componentRef, toggleCallback);
    var pressable = (0, interactive_hooks_1.usePressableState)(tslib_1.__assign(tslib_1.__assign({}, rest), { onPress: toggleCheckedWithFocus }));
    var buttonRef = (0, interactive_hooks_1.useViewCommandFocus)(componentRef);
    var onKeysPressed = React.useCallback(function (e) {
        var invokeKey = e.nativeEvent.key === ' ' || e.nativeEvent.key === 'Enter';
        if (!disabled && invokeKey) {
            toggleCallback(e);
            return;
        }
        var isRtl = react_native_1.I18nManager.isRTL;
        var isArrowClose = isSubmenu && ((isRtl && e.nativeEvent.key === 'ArrowRight') || (!isRtl && e.nativeEvent.key === 'ArrowLeft'));
        if (isArrowClose) {
            onArrowClose === null || onArrowClose === void 0 ? void 0 : onArrowClose(e);
        }
    }, [disabled, isSubmenu, onArrowClose, toggleCallback]);
    var keys = disabled ? [] : isSubmenu ? useMenuItem_1.submenuTriggerKeys : useMenuItem_1.triggerKeys;
    var onKeyProps = interactive_hooks_1.useKeyDownProps.apply(void 0, tslib_1.__spreadArray([onKeysPressed], keys, false));
    var accessibilityActionsProp = accessibilityActions
        ? tslib_1.__spreadArray(tslib_1.__spreadArray([], defaultAccessibilityActions, true), accessibilityActions, true) : defaultAccessibilityActions;
    var onAccessibilityActionProp = React.useCallback(function (event) {
        if (!disabled) {
            if (event.nativeEvent.actionName === 'Toggle') {
                toggleCallback(event);
            }
            onAccessibilityAction && onAccessibilityAction(event);
        }
    }, [disabled, toggleCallback, onAccessibilityAction]);
    (0, useMenuItem_1.useHoverFocusEffect)(pressable.state.hovered, componentRef);
    var _d = React.useState(!pressable.state.hovered), enableFocusRing = _d[0], setEnableFocusRing = _d[1];
    var onHoverIn = React.useCallback(function (e) {
        pressable.props.onHoverIn(e);
        // when it's a hover focus, set enableFocusRing explicitly to false
        if (!pressable.state.focused) {
            setEnableFocusRing(false);
        }
    }, [pressable]);
    var onFocus = React.useCallback(function (e) {
        pressable.props.onFocus(e);
        // when it's not a hover focus, set enableFocusRing explicitly to true
        if (!pressable.state.focused) {
            setEnableFocusRing(true);
        }
    }, [pressable]);
    // Track the ref and disabled props on this menu item so the MenuList can handle Home and End keypresses.
    (0, useMenuList_1.useMenuItemTracking)(componentRef, disabled);
    var state = tslib_1.__assign(tslib_1.__assign({}, pressable.state), { checked: isChecked, disabled: disabled, hasIcons: hasIcons, hasTooltips: hasTooltips });
    return {
        props: tslib_1.__assign(tslib_1.__assign(tslib_1.__assign({}, pressable.props), { onHoverIn: react_native_1.Platform.select({
                macos: pressable.props.onHoverIn,
                default: onHoverIn, // win32
            }), onFocus: react_native_1.Platform.select({
                macos: pressable.props.onFocus,
                default: onFocus, // win32
            }), accessible: accessible !== null && accessible !== void 0 ? accessible : true, accessibilityActions: accessibilityActionsProp, accessibilityLabel: accessibilityLabel, accessibilityRole: 'menuitem', accessibilityState: getAccessibilityState(disabled, state.checked, accessibilityState), disabled: disabled, enableFocusRing: react_native_1.Platform.select({
                macos: false,
                default: enableFocusRing, // win32
            }), focusable: react_native_1.Platform.select({
                macos: !disabled,
                default: true, // win32
            }), onAccessibilityAction: onAccessibilityActionProp, ref: buttonRef }), onKeyProps),
        state: state,
    };
};
exports.useMenuCheckboxInteraction = useMenuCheckboxInteraction;
//# sourceMappingURL=useMenuItemCheckbox.js.map