"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MenuList = exports.menuListLookup = void 0;
var tslib_1 = require("tslib");
/** @jsxRuntime classic */
/** @jsx withSlots */
var react_1 = tslib_1.__importDefault(require("react"));
var react_native_1 = require("react-native");
var focus_zone_1 = require("@fluentui-react-native/focus-zone");
var framework_1 = require("@fluentui-react-native/framework");
var MenuList_styling_1 = require("./MenuList.styling");
var MenuList_types_1 = require("./MenuList.types");
var useMenuList_1 = require("./useMenuList");
var useMenuListContextValue_1 = require("./useMenuListContextValue");
var menuListContext_1 = require("../context/menuListContext");
var MenuStack = (0, framework_1.stagedComponent)(function (props) {
    var gap = props.gap, rest = tslib_1.__rest(props, ["gap"]);
    return function (final, children) {
        if (gap && gap > 0 && children) {
            // eslint-disable-next-line @typescript-eslint/ban-ts-comment
            // @ts-ignore - GH:1684, fix typing error
            children = react_1.default.Children.map(children, function (child, index) {
                if (react_1.default.isValidElement(child) && index > 0) {
                    return react_1.default.cloneElement(child, (0, framework_1.mergeProps)(child.props, { style: { marginTop: gap } }));
                }
                return child;
            });
        }
        return (0, framework_1.withSlots)(react_native_1.View, tslib_1.__assign({}, (0, framework_1.mergeProps)(rest, final)), children);
    };
});
MenuStack.displayName = 'MenuStack';
var shouldHaveFocusZone = ['macos', 'win32'].includes(react_native_1.Platform.OS);
var focusLandsOnContainer = react_native_1.Platform.OS === 'macos';
var hasCircularNavigation = react_native_1.Platform.OS === 'win32';
var menuListLookup = function (layer, state, userProps) {
    return state[layer] || userProps[layer] || layer === 'hasMaxHeight';
};
exports.menuListLookup = menuListLookup;
exports.MenuList = (0, framework_1.compose)(tslib_1.__assign(tslib_1.__assign({ displayName: MenuList_types_1.menuListName }, MenuList_styling_1.stylingSettings), { slots: {
        root: MenuStack,
        scrollView: react_native_1.ScrollView,
        focusZone: shouldHaveFocusZone ? focus_zone_1.FocusZone : react_1.default.Fragment,
    }, useRender: function (userProps, useSlots) {
        var menuList = (0, useMenuList_1.useMenuList)(userProps);
        var menuListContextValue = (0, useMenuListContextValue_1.useMenuListContextValue)(menuList);
        var Slots = useSlots(menuList.props, function (layer) { return (0, exports.menuListLookup)(layer, menuList, userProps); });
        return function (_final, children) {
            var itemCount = react_1.default.Children.toArray(children).filter(function (child) { return react_1.default.isValidElement(child) && child.type.displayName !== 'MenuDivider'; }).length;
            var itemPosition = 0;
            var childrenWithSet = react_1.default.Children.toArray(children).map(function (child) {
                var _a, _b;
                if (react_1.default.isValidElement(child)) {
                    if (child.type.displayName !== 'MenuDivider') {
                        itemPosition++;
                    }
                    return react_1.default.cloneElement(child, tslib_1.__assign({ accessibilityPositionInSet: (_a = child.props.accessibilityPositionInSet) !== null && _a !== void 0 ? _a : itemPosition, accessibilitySetSize: (_b = child.props.accessibilitySetSize) !== null && _b !== void 0 ? _b : itemCount }, (child.props.tooltip && { alwaysShowToolTip: true })));
                }
                return child;
            });
            var shouldHaveScrollView = react_native_1.Platform.OS === 'macos' || menuList.hasMaxHeight || menuList.hasMaxWidth;
            var ScrollViewWrapper = shouldHaveScrollView ? Slots.scrollView : react_1.default.Fragment;
            var hasMenuGroupChild = react_1.default.Children.toArray(children).some(function (child) { return child && child.type && child.type.displayName === 'MenuGroup'; });
            // On win32, tab navigation should only be enabled when we have menu groups.
            var hasTabNavigation = react_native_1.Platform.OS === 'win32' && hasMenuGroupChild;
            var content = ((0, framework_1.withSlots)(Slots.root, null,
                (0, framework_1.withSlots)(ScrollViewWrapper
                // avoid error that fires when props are passed into React.fragment
                , tslib_1.__assign({}, (shouldHaveScrollView && {
                    showsVerticalScrollIndicator: menuList.hasMaxHeight,
                    showsHorizontalScrollIndicator: menuList.hasMaxWidth,
                })),
                    (0, framework_1.withSlots)(Slots.focusZone
                    // avoid error that fires when props are passed into React.fragment
                    , tslib_1.__assign({}, (shouldHaveFocusZone && {
                        componentRef: focusLandsOnContainer && menuList.focusZoneRef,
                        focusZoneDirection: 'vertical',
                        defaultTabbableElement: focusLandsOnContainer && menuList.focusZoneRef,
                        enableFocusRing: false,
                        isCircularNavigation: hasCircularNavigation,
                        tabKeyNavigation: hasTabNavigation ? 'Normal' : 'None',
                    })), childrenWithSet))));
            return (0, framework_1.withSlots)(menuListContext_1.MenuListProvider, { value: menuListContextValue }, content);
        };
    } }));
//# sourceMappingURL=MenuList.js.map