"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useMenuPopover = void 0;
var tslib_1 = require("tslib");
var react_1 = tslib_1.__importDefault(require("react"));
var react_native_1 = require("react-native");
var menuContext_1 = require("../context/menuContext");
var controlledDismissBehaviors = ['preventDismissOnKeyDown', 'preventDismissOnClickOutside'];
var stopPropagationKeys = ['ArrowUp', 'ArrowDown', 'ArrowLeft', 'ArrowRight', 'Tab', 'Home', 'End', 'Escape'];
var useMenuPopover = function (props) {
    var _a, _b;
    var context = (0, menuContext_1.useMenuContext)();
    var setOpen = context.setOpen, triggerRef = context.triggerRef, isControlled = context.isControlled, isSubmenu = context.isSubmenu, openOnHover = context.openOnHover, parentPopoverHoverOutTimer = context.parentPopoverHoverOutTimer, popoverHoverOutTimer = context.popoverHoverOutTimer, setPopoverHoverOutTimer = context.setPopoverHoverOutTimer, shouldFocusOnContainer = context.shouldFocusOnContainer, triggerHoverOutTimer = context.triggerHoverOutTimer;
    var onKeyDownProp = props.onKeyDown, onKeyUpProp = props.onKeyUp;
    var onDismiss = react_1.default.useCallback(function () {
        var _a;
        (_a = props.onDismiss) === null || _a === void 0 ? void 0 : _a.call(props);
        setOpen(undefined, false /* isOpen */), [setOpen];
    }, [props.onDismiss, setOpen]);
    var dismissBehaviors = isControlled ? controlledDismissBehaviors : undefined;
    var directionalHint = (_a = props.directionalHint) !== null && _a !== void 0 ? _a : getDirectionalHint(isSubmenu, react_native_1.I18nManager.isRTL);
    var setInitialFocus = true;
    var doNotTakePointerCapture = (_b = props.doNotTakePointerCapture) !== null && _b !== void 0 ? _b : openOnHover;
    var accessibilityRole = 'menu';
    var onMouseEnter = react_1.default.useCallback(function () {
        clearTimeout(triggerHoverOutTimer);
        clearTimeout(popoverHoverOutTimer);
        clearTimeout(parentPopoverHoverOutTimer);
    }, [parentPopoverHoverOutTimer, popoverHoverOutTimer, triggerHoverOutTimer]);
    var onMouseLeave = react_1.default.useCallback(function () {
        if (!openOnHover) {
            return;
        }
        var timer = setTimeout(function () {
            setOpen(undefined, false /* isOpen */);
        }, 500);
        setPopoverHoverOutTimer(timer);
    }, [openOnHover, setOpen, setPopoverHoverOutTimer]);
    var onKeyDown = react_1.default.useCallback(function (e) {
        onKeyDownProp && onKeyDownProp(e);
        // Mark key events that move selection as handled.
        // These key events are handled on the native side.
        if (stopPropagationKeys.includes(e.nativeEvent.key)) {
            e.stopPropagation();
        }
    }, [onKeyDownProp]);
    var onKeyUp = react_1.default.useCallback(function (e) {
        onKeyUpProp && onKeyUpProp(e);
        // Mark key events that move selection as handled.
        // These key events are handled on the native side.
        if (stopPropagationKeys.includes(e.nativeEvent.key)) {
            e.stopPropagation();
        }
    }, [onKeyUpProp]);
    var _c = react_1.default.useState(shouldFocusOnContainer), canFocusOnPopover = _c[0], setCanFocusOnPopover = _c[1];
    var onBlur = react_1.default.useCallback(function () {
        setCanFocusOnPopover(false);
    }, [setCanFocusOnPopover]);
    react_1.default.useEffect(function () {
        return function cleanup() {
            clearTimeout(popoverHoverOutTimer);
        };
    });
    return {
        props: {
            accessibilityRole: accessibilityRole,
            target: triggerRef,
            onDismiss: onDismiss,
            onShow: props.onShow,
            directionalHint: directionalHint,
            dismissBehaviors: dismissBehaviors,
            doNotTakePointerCapture: doNotTakePointerCapture,
            setInitialFocus: setInitialFocus,
        },
        innerView: {
            onMouseEnter: onMouseEnter,
            onMouseLeave: onMouseLeave,
            onKeyDown: onKeyDown,
            onKeyUp: onKeyUp,
            accessible: shouldFocusOnContainer,
            focusable: canFocusOnPopover,
            onBlur: onBlur,
        },
    };
};
exports.useMenuPopover = useMenuPopover;
var getDirectionalHint = function (isSubmenu, isRtl) {
    if (!isSubmenu) {
        return undefined;
    }
    if (isRtl) {
        return 'leftTopEdge';
    }
    return 'rightTopEdge';
};
//# sourceMappingURL=useMenuPopover.js.map