"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useMenuTrigger = void 0;
var tslib_1 = require("tslib");
var react_1 = tslib_1.__importDefault(require("react"));
var react_native_1 = require("react-native");
var useMergeRefs_1 = require("./useMergeRefs");
var consts_1 = require("../consts");
var menuContext_1 = require("../context/menuContext");
var baseAccessibilityActions = react_native_1.Platform.OS === 'win32' ? [{ name: 'Expand' }, { name: 'Collapse' }] : [];
var expandedState = { expanded: true };
var collapsedState = { expanded: false };
var useMenuTrigger = function (childProps) {
    var context = (0, menuContext_1.useMenuContext)();
    var _a = context.hoverDelay, hoverDelay = _a === void 0 ? consts_1.hoverDelayDefault : _a, open = context.open, openOnHover = context.openOnHover, popoverHoverOutTimer = context.popoverHoverOutTimer, setOpen = context.setOpen, setTriggerHoverOutTimer = context.setTriggerHoverOutTimer, triggerHoverOutTimer = context.triggerHoverOutTimer, triggerRef = context.triggerRef;
    var childAccessibilityActions = childProps.accessibilityActions, childAccessibilityState = childProps.accessibilityState, childOnAccessibilityAction = childProps.onAccessibilityAction, childAccessibilityPositionInSet = childProps.accessibilityPositionInSet, // win32
    childAccessibilitySetSize = childProps.accessibilitySetSize, // win32
    childOnClick = childProps.onClick, childOnHoverIn = childProps.onHoverIn, childOnHoverOut = childProps.onHoverOut, childComponentRef = childProps.componentRef;
    var accessibilityActions = react_1.default.useMemo(function () {
        if (childAccessibilityActions) {
            return tslib_1.__spreadArray(tslib_1.__spreadArray([], baseAccessibilityActions, true), childAccessibilityActions, true);
        }
        return baseAccessibilityActions;
    }, [childAccessibilityActions]);
    var accessibilityState = react_1.default.useMemo(function () {
        var baseState = open ? expandedState : collapsedState;
        if (childAccessibilityState) {
            return tslib_1.__assign(tslib_1.__assign({}, baseState), childAccessibilityState);
        }
        return baseState;
    }, [childAccessibilityState, open]);
    var onAccessibilityAction = react_1.default.useCallback(function (e) {
        if (react_native_1.Platform.OS === 'win32') {
            switch (e.nativeEvent.actionName) {
                case 'Expand':
                    setOpen(e, true /* isOpen */);
                    break;
                case 'Collapse':
                    setOpen(e, false /* isOpen */);
                    break;
            }
        }
        childOnAccessibilityAction && childOnAccessibilityAction(e);
    }, [childOnAccessibilityAction, setOpen]);
    var onHoverIn = react_1.default.useCallback(function (e) {
        if (openOnHover) {
            clearTimeout(popoverHoverOutTimer);
            clearTimeout(triggerHoverOutTimer);
            e.persist();
            setTimeout(function () {
                setOpen(e, true /* isOpen */);
            }, hoverDelay);
        }
        childOnHoverIn && childOnHoverIn(e);
    }, [childOnHoverIn, hoverDelay, openOnHover, setOpen, triggerHoverOutTimer, popoverHoverOutTimer]);
    var onHoverOut = react_1.default.useCallback(function (e) {
        if (openOnHover) {
            e.persist();
            var timer = setTimeout(function () {
                setOpen(e, false /* isOpen */);
            }, hoverDelay);
            setTriggerHoverOutTimer(timer);
        }
        childOnHoverOut && childOnHoverOut(e);
    }, [childOnHoverOut, hoverDelay, openOnHover, setOpen, setTriggerHoverOutTimer]);
    var onClick = react_1.default.useCallback(function (e) {
        setOpen(e, !open);
        childOnClick && childOnClick(e);
    }, [childOnClick, open, setOpen]);
    var ref = (0, useMergeRefs_1.useMergedRefs)(triggerRef, childComponentRef);
    return {
        props: {
            onClick: onClick,
            onHoverIn: onHoverIn,
            onHoverOut: onHoverOut,
            componentRef: ref,
            accessibilityState: accessibilityState,
            accessibilityActions: accessibilityActions,
            onAccessibilityAction: onAccessibilityAction,
            accessibilityPositionInSet: childAccessibilityPositionInSet !== null && childAccessibilityPositionInSet !== void 0 ? childAccessibilityPositionInSet : context.accessibilityPositionInSet,
            accessibilitySetSize: childAccessibilitySetSize !== null && childAccessibilitySetSize !== void 0 ? childAccessibilitySetSize : context.accessibilitySetSize, // win32
        },
        hasSubmenu: context.isSubmenu,
    };
};
exports.useMenuTrigger = useMenuTrigger;
//# sourceMappingURL=useMenuTrigger.js.map