"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var React = tslib_1.__importStar(require("react"));
var button_1 = require("@fluentui-react-native/button");
var renderer = tslib_1.__importStar(require("react-test-renderer"));
var Menu_1 = require("../Menu/Menu");
var MenuDivider_1 = require("../MenuDivider/MenuDivider");
var MenuGroup_1 = require("../MenuGroup");
var MenuGroupHeader_1 = require("../MenuGroupHeader");
var MenuItem_1 = require("../MenuItem/MenuItem");
var MenuItemCheckbox_1 = require("../MenuItemCheckbox/MenuItemCheckbox");
var MenuItemRadio_1 = require("../MenuItemRadio/MenuItemRadio");
var MenuList_1 = require("../MenuList/MenuList");
var MenuPopover_1 = tslib_1.__importDefault(require("../MenuPopover/MenuPopover"));
var MenuTrigger_1 = tslib_1.__importDefault(require("../MenuTrigger/MenuTrigger"));
describe('Menu component tests', function () {
    it('Menu default', function () {
        var tree = renderer
            .create(React.createElement(Menu_1.Menu, null,
            React.createElement(MenuTrigger_1.default, null,
                React.createElement(button_1.ButtonV1, null, "Default")),
            React.createElement(MenuPopover_1.default, null,
                React.createElement(MenuList_1.MenuList, null,
                    React.createElement(MenuItem_1.MenuItem, null, "Option 1")))))
            .toJSON();
        expect(tree).toMatchSnapshot();
    });
    it('Menu open', function () {
        var tree = renderer
            .create(React.createElement(Menu_1.Menu, { open: true },
            React.createElement(MenuTrigger_1.default, null,
                React.createElement(button_1.ButtonV1, null, "Open")),
            React.createElement(MenuPopover_1.default, null,
                React.createElement(MenuList_1.MenuList, null,
                    React.createElement(MenuItem_1.MenuItem, null, "Option 1")))))
            .toJSON();
        expect(tree).toMatchSnapshot();
    });
    it('Menu defaultOpen', function () {
        var tree = renderer
            .create(React.createElement(Menu_1.Menu, { defaultOpen: true },
            React.createElement(MenuTrigger_1.default, null,
                React.createElement(button_1.ButtonV1, null, "Open")),
            React.createElement(MenuPopover_1.default, null,
                React.createElement(MenuList_1.MenuList, null,
                    React.createElement(MenuItem_1.MenuItem, null, "Option 1"),
                    React.createElement(MenuItem_1.MenuItem, { disabled: true }, "Option 2")))))
            .toJSON();
        expect(tree).toMatchSnapshot();
    });
    it('Menu open checkbox and divider', function () {
        var tree = renderer
            .create(React.createElement(Menu_1.Menu, { open: true },
            React.createElement(MenuTrigger_1.default, null,
                React.createElement(button_1.ButtonV1, null, "Open")),
            React.createElement(MenuPopover_1.default, null,
                React.createElement(MenuList_1.MenuList, null,
                    React.createElement(MenuItemCheckbox_1.MenuItemCheckbox, { name: "Option 1" }, "Option 1"),
                    React.createElement(MenuDivider_1.MenuDivider, null),
                    React.createElement(MenuItemCheckbox_1.MenuItemCheckbox, { disabled: true, name: "Option 2" }, "Option 2")))))
            .toJSON();
        expect(tree).toMatchSnapshot();
    });
    it('Menu open radio', function () {
        var tree = renderer
            .create(React.createElement(Menu_1.Menu, { open: true },
            React.createElement(MenuTrigger_1.default, null,
                React.createElement(button_1.ButtonV1, null, "Open")),
            React.createElement(MenuPopover_1.default, null,
                React.createElement(MenuList_1.MenuList, null,
                    React.createElement(MenuItemRadio_1.MenuItemRadio, { name: "Option 1" }, "Option 1"),
                    React.createElement(MenuItemRadio_1.MenuItemRadio, { name: "Option 2" }, "Option 2")))))
            .toJSON();
        expect(tree).toMatchSnapshot();
    });
    it('Menu open checkbox defaultChecked', function () {
        var tree = renderer
            .create(React.createElement(Menu_1.Menu, { open: true, defaultChecked: ['Option 1'] },
            React.createElement(MenuTrigger_1.default, null,
                React.createElement(button_1.ButtonV1, null, "Open")),
            React.createElement(MenuPopover_1.default, null,
                React.createElement(MenuList_1.MenuList, null,
                    React.createElement(MenuItemCheckbox_1.MenuItemCheckbox, { name: "Option 1" }, "Option 1"),
                    React.createElement(MenuDivider_1.MenuDivider, null),
                    React.createElement(MenuItemCheckbox_1.MenuItemCheckbox, { name: "Option 2" }, "Option 2")))))
            .toJSON();
        expect(tree).toMatchSnapshot();
    });
    it('Menu open checkbox checked', function () {
        var tree = renderer
            .create(React.createElement(Menu_1.Menu, { open: true, checked: ['Option 1'] },
            React.createElement(MenuTrigger_1.default, null,
                React.createElement(button_1.ButtonV1, null, "Open")),
            React.createElement(MenuPopover_1.default, null,
                React.createElement(MenuList_1.MenuList, null,
                    React.createElement(MenuItemCheckbox_1.MenuItemCheckbox, { name: "Option 1" }, "Option 1"),
                    React.createElement(MenuDivider_1.MenuDivider, null),
                    React.createElement(MenuItemCheckbox_1.MenuItemCheckbox, { name: "Option 2" }, "Option 2")))))
            .toJSON();
        expect(tree).toMatchSnapshot();
    });
    it('Menu submenu', function () {
        var tree = renderer
            .create(React.createElement(Menu_1.Menu, { open: true },
            React.createElement(MenuTrigger_1.default, null,
                React.createElement(button_1.ButtonV1, null, "Default")),
            React.createElement(MenuPopover_1.default, null,
                React.createElement(MenuList_1.MenuList, null,
                    React.createElement(MenuItem_1.MenuItem, null, "Option 1"),
                    React.createElement(Menu_1.Menu, null,
                        React.createElement(MenuTrigger_1.default, null,
                            React.createElement(MenuItem_1.MenuItem, null, "Option 2")),
                        React.createElement(MenuPopover_1.default, null,
                            React.createElement(MenuList_1.MenuList, null,
                                React.createElement(MenuItem_1.MenuItem, null, "Option 1"))))))))
            .toJSON();
        expect(tree).toMatchSnapshot();
    });
    // Note the capital T the "Tip" (in the snapshot)
    // It is intentional as it matches the same prop in NetUI
    it('Menu alwaysShowToolTip', function () {
        var tree = renderer
            .create(React.createElement(Menu_1.Menu, null,
            React.createElement(MenuTrigger_1.default, null,
                React.createElement(button_1.ButtonV1, { tooltip: "A Tooltip" }, "Button")),
            React.createElement(MenuPopover_1.default, null,
                React.createElement(MenuList_1.MenuList, null,
                    React.createElement(MenuItem_1.MenuItem, null, "Test"),
                    React.createElement(MenuItem_1.MenuItem, { tooltip: "Second" }, "With Tooltip"),
                    React.createElement(MenuItemRadio_1.MenuItemRadio, { name: "Radio", tooltip: "Third" }, "Radio Tooltip"),
                    React.createElement(MenuItemCheckbox_1.MenuItemCheckbox, { name: "Check", tooltip: "Fourth" }, "Checkbox Tooltip")))))
            .toJSON();
        expect(tree).toMatchSnapshot();
    });
});
it('Menu open menu group and menu header', function () {
    var tree = renderer
        .create(React.createElement(Menu_1.Menu, { open: true },
        React.createElement(MenuTrigger_1.default, null,
            React.createElement(button_1.ButtonV1, null, "Open")),
        React.createElement(MenuPopover_1.default, null,
            React.createElement(MenuList_1.MenuList, null,
                React.createElement(MenuGroup_1.MenuGroup, null,
                    React.createElement(MenuGroupHeader_1.MenuGroupHeader, null, "Header 1"),
                    React.createElement(MenuItem_1.MenuItem, null, "Option 1")),
                React.createElement(MenuDivider_1.MenuDivider, null),
                React.createElement(MenuGroup_1.MenuGroup, null,
                    React.createElement(MenuGroupHeader_1.MenuGroupHeader, null, "Header 2"),
                    React.createElement(MenuItem_1.MenuItem, null, "Option 1"))))))
        .toJSON();
    expect(tree).toMatchSnapshot();
});
//# sourceMappingURL=Menu.test.js.map