import { __assign } from "tslib";
import React from 'react';
import { Platform } from 'react-native';
import { isMouseEvent } from '@fluentui-react-native/interactive-hooks';
import { useMenuContext } from '../context/menuContext';
// Due to how events get fired we get double notifications
// for the same event causing us to immediately reopen
// a menu when we close it. Adding in a delay to prevent
// this behavior.
var delayOpen = 150;
export var useMenu = function (props) {
    var triggerRef = React.useRef();
    var context = useMenuContext();
    var isSubmenu = context.triggerRef !== null;
    var isOpenControlled = typeof props.open !== 'undefined';
    var _a = useMenuOpenState(isOpenControlled, props, context.setOpen), open = _a[0], shouldFocusOnContainer = _a[1], setOpen = _a[2];
    var _b = useMenuCheckedState(props), checked = _b[0], onCheckedChange = _b[1];
    // Default behavior for submenu is to open on hover
    // the ...props line below will override this behavior for a submenu
    // or apply openOnHover if passed into a root Menu.
    var openOnHover = isSubmenu;
    // We need to be able to cancel the timer that gets set on
    // hover out of the parent popover if the parent popover
    // is also set to open/close on hover out. Otherwise
    // the parent menu will close when the timeout passes.
    var parentPopoverHoverOutTimer = isSubmenu ? context.popoverHoverOutTimer : undefined;
    return __assign(__assign({ openOnHover: openOnHover }, props), { open: open, setOpen: setOpen, shouldFocusOnContainer: shouldFocusOnContainer, checked: checked, onCheckedChange: onCheckedChange, triggerRef: triggerRef, isSubmenu: isSubmenu, isControlled: isOpenControlled, parentPopoverHoverOutTimer: parentPopoverHoverOutTimer });
};
var useMenuOpenState = function (isControlled, props, parentSetOpen) {
    var defaultOpen = props.defaultOpen, onOpenChange = props.onOpenChange, open = props.open;
    var initialState = typeof defaultOpen !== 'undefined' ? defaultOpen : !!open;
    var _a = React.useState(initialState), openInternal = _a[0], setOpenInternal = _a[1];
    var _b = React.useState(undefined), shouldFocusOnContainer = _b[0], setShouldFocusOnContainer = _b[1];
    var state = isControlled ? open : openInternal;
    var lastCloseTimestampRef = React.useRef(-1);
    var setOpen = React.useCallback(function (e, isOpen, bubble) {
        var openPrev = state;
        if (!isControlled && (!isOpen || lastCloseTimestampRef.current + delayOpen <= Date.now())) {
            setOpenInternal(isOpen);
        }
        if (isOpen) {
            if (Platform.OS === 'win32' && isMouseEvent(e)) {
                setShouldFocusOnContainer(true);
            }
            else {
                setShouldFocusOnContainer(false);
            }
        }
        if (!isOpen) {
            setShouldFocusOnContainer(undefined);
            lastCloseTimestampRef.current = Date.now();
        }
        if (onOpenChange && openPrev !== isOpen) {
            onOpenChange(e, isOpen);
        }
        if (bubble && parentSetOpen) {
            parentSetOpen(e, isOpen, bubble);
        }
    }, [isControlled, state, onOpenChange, setOpenInternal, parentSetOpen]);
    return [state, shouldFocusOnContainer, setOpen];
};
var useMenuCheckedState = function (props) {
    var _a;
    var checked = props.checked, defaultChecked = props.defaultChecked, onCheckedChangeOriginal = props.onCheckedChange;
    var _b = React.useState((_a = defaultChecked !== null && defaultChecked !== void 0 ? defaultChecked : checked) !== null && _a !== void 0 ? _a : []), checkedInternal = _b[0], setCheckedInternal = _b[1];
    var isControlled = typeof checked !== 'undefined';
    var state = isControlled ? checked : checkedInternal;
    var onCheckedChange = React.useCallback(function (e, checked) {
        if (!isControlled) {
            setCheckedInternal(checked);
        }
        onCheckedChangeOriginal === null || onCheckedChangeOriginal === void 0 ? void 0 : onCheckedChangeOriginal(e, checked);
    }, [isControlled, setCheckedInternal, onCheckedChangeOriginal]);
    return [state, onCheckedChange];
};
//# sourceMappingURL=useMenu.js.map