import { __assign, __rest } from "tslib";
/** @jsxRuntime classic */
/** @jsx withSlots */
import React from 'react';
import { Platform, View } from 'react-native';
import { FocusZone } from '@fluentui-react-native/focus-zone';
import { compose, mergeProps, withSlots } from '@fluentui-react-native/framework';
import { menuGroupName } from './MenuGroup.types';
// Intentionally not enabled on macOS to match system context menus
var hasFocusZone = ['win32'].includes(Platform.OS);
export var MenuGroup = compose({
    displayName: menuGroupName,
    slots: {
        root: View,
        contentWrapper: hasFocusZone ? FocusZone : React.Fragment,
    },
    useRender: function (userProps, useSlots) {
        var Slots = useSlots(userProps);
        return function (final, children) {
            var _a;
            var mergedProps = __rest(mergeProps(userProps, final), []);
            var itemPosition = 0;
            var childrenWithSet = React.Children.toArray(children).map(function (child) {
                var _a, _b;
                if (React.isValidElement(child)) {
                    var itemCount = React.Children.toArray(children).filter(function (child) {
                        return React.isValidElement(child) &&
                            child.type.displayName !== 'MenuGroupHeader' &&
                            child.type.displayName !== 'MenuDivider';
                    }).length;
                    if (child.type.displayName !== 'MenuGroupHeader' && child.type.displayName !== 'MenuDivider') {
                        itemPosition++;
                    }
                    return React.cloneElement(child, {
                        accessibilityPositionInSet: (_a = child.props.accessibilityPositionInSet) !== null && _a !== void 0 ? _a : itemPosition,
                        accessibilitySetSize: (_b = child.props.accessibilitySetSize) !== null && _b !== void 0 ? _b : itemCount, //win32
                    });
                }
                return child;
            });
            // Check if this MenuGroup has a MenuGroupHeader. If so, use the MenuGroupHeader
            // as the accessibilityLabel for the MenuGroup.
            var menuGroupHeader = React.Children.toArray(children).find(function (child) { return React.isValidElement(child) && child.type.displayName === 'MenuGroupHeader'; });
            // On win32, in order for assistive technology to read a group, it must have a name which is why
            // we use a string with a space as the default accessibilityLabel for MenuGroup.
            // If an empty string was used, the group context would not be read.
            var menuGroupA11yLabel = ' ';
            if (menuGroupHeader && typeof menuGroupHeader.props.children === 'string') {
                menuGroupA11yLabel = menuGroupHeader.props.children;
            }
            return (withSlots(Slots.root, __assign({}, mergedProps, (Platform.OS == 'win32' && {
                accessible: true,
                accessibilityRole: 'group',
                accessibilityLabel: (_a = mergedProps.accessibilityLabel) !== null && _a !== void 0 ? _a : menuGroupA11yLabel,
            })),
                withSlots(Slots.contentWrapper
                // avoid error that fires when props are passed into React.fragment
                , __assign({}, (hasFocusZone && {
                    focusZoneDirection: 'vertical',
                    enableFocusRing: false,
                    navigateAtEnd: 'NavigateContinue',
                })), childrenWithSet)));
        };
    },
});
//# sourceMappingURL=MenuGroup.js.map