import { __assign, __rest, __spreadArray } from "tslib";
import * as React from 'react';
import { I18nManager, Platform } from 'react-native';
import { memoize } from '@fluentui-react-native/framework';
import { isKeyPressEvent, usePressableState, useKeyDownProps, useViewCommandFocus } from '@fluentui-react-native/interactive-hooks';
import { useMenuContext } from '../context/menuContext';
import { useMenuListContext } from '../context/menuListContext';
import { useMenuTriggerContext } from '../context/menuTriggerContext';
import { useMenuItemTracking } from '../MenuList/useMenuList';
export var triggerKeys = [' ', 'Enter'];
export var submenuTriggerKeys = __spreadArray(['ArrowLeft', 'ArrowRight'], triggerKeys, true);
export var useMenuItem = function (props) {
    // attach the pressable state handlers
    var defaultComponentRef = React.useRef(null);
    var accessible = props.accessible, onClick = props.onClick, accessibilityState = props.accessibilityState, _a = props.componentRef, componentRef = _a === void 0 ? defaultComponentRef : _a, _b = props.disabled, disabled = _b === void 0 ? false : _b, persistOnClick = props.persistOnClick, rest = __rest(props, ["accessible", "onClick", "accessibilityState", "componentRef", "disabled", "persistOnClick"]);
    var _c = useMenuContext(), isSubmenu = _c.isSubmenu, persistOnItemClick = _c.persistOnItemClick, setOpen = _c.setOpen;
    var _d = useMenuListContext(), hasCheckmarks = _d.hasCheckmarks, hasIcons = _d.hasIcons, hasTooltips = _d.hasTooltips, onArrowClose = _d.onArrowClose;
    var isTrigger = useMenuTriggerContext();
    var shouldPersist = persistOnClick !== null && persistOnClick !== void 0 ? persistOnClick : persistOnItemClick;
    var hasSubmenu = isSubmenu && isTrigger;
    var onInvoke = React.useCallback(function (e) {
        var _a;
        var isRtl = I18nManager.isRTL;
        var isArrowKey = isKeyPressEvent(e) && (e.nativeEvent.key === 'ArrowLeft' || e.nativeEvent.key === 'ArrowRight');
        var isArrowOpen = hasSubmenu &&
            isKeyPressEvent(e) &&
            ((isRtl && e.nativeEvent.key === 'ArrowLeft') || (!isRtl && e.nativeEvent.key === 'ArrowRight'));
        if (!disabled && (!isArrowKey || isArrowOpen)) {
            (_a = componentRef === null || componentRef === void 0 ? void 0 : componentRef.current) === null || _a === void 0 ? void 0 : _a.blur();
            onClick === null || onClick === void 0 ? void 0 : onClick(e);
        }
        if (!hasSubmenu && !isArrowKey && !shouldPersist) {
            setOpen(e, false /*isOpen*/, true /*bubble*/);
        }
        var isArrowClose = isKeyPressEvent(e) && ((isRtl && e.nativeEvent.key === 'ArrowRight') || (!isRtl && e.nativeEvent.key === 'ArrowLeft'));
        if (isArrowClose) {
            onArrowClose === null || onArrowClose === void 0 ? void 0 : onArrowClose(e);
        }
    }, [componentRef, disabled, hasSubmenu, onArrowClose, onClick, setOpen, shouldPersist]);
    var pressable = usePressableState(__assign(__assign({}, rest), { onPress: onInvoke }));
    var itemRef = useViewCommandFocus(componentRef);
    var keys = disabled ? [] : isSubmenu ? submenuTriggerKeys : triggerKeys;
    // Explicitly override onKeyDown to override the native behavior of moving focus with arrow keys.
    var onKeyDownProps = useKeyDownProps.apply(void 0, __spreadArray([onInvoke], keys, false));
    useHoverFocusEffect(pressable.state.hovered, componentRef);
    var _e = React.useState(!pressable.state.hovered), enableFocusRing = _e[0], setEnableFocusRing = _e[1];
    var onHoverIn = React.useCallback(function (e) {
        pressable.props.onHoverIn(e);
        // when it's a hover focus, set enableFocusRing explicitly to false
        if (!pressable.state.focused) {
            setEnableFocusRing(false);
        }
    }, [pressable]);
    var onFocus = React.useCallback(function (e) {
        pressable.props.onFocus(e);
        // when it's not a hover focus, set enableFocusRing explicitly to true
        if (!pressable.state.focused) {
            setEnableFocusRing(true);
        }
    }, [pressable]);
    // Track the ref and disabled props on this menu item so the MenuList can handle Home and End keypresses.
    useMenuItemTracking(componentRef, disabled);
    return {
        props: __assign(__assign(__assign({}, pressable.props), { onHoverIn: Platform.select({
                macos: pressable.props.onHoverIn,
                default: onHoverIn, // win32
            }), onFocus: Platform.select({
                macos: pressable.props.onFocus,
                default: onFocus, // win32
            }), accessible: accessible !== null && accessible !== void 0 ? accessible : true, accessibilityRole: 'menuitem', onAccessibilityTap: props.onAccessibilityTap || onInvoke, accessibilityState: getAccessibilityState(disabled, accessibilityState), disabled: disabled, enableFocusRing: Platform.select({
                macos: false,
                default: enableFocusRing, // win32
            }), focusable: Platform.select({
                macos: !disabled,
                default: true, // win32
            }), ref: itemRef }), onKeyDownProps),
        state: __assign(__assign({}, pressable.state), { hasSubmenu: hasSubmenu, hasIcons: hasIcons, hasCheckmarks: hasCheckmarks, hasTooltips: hasTooltips }),
    };
};
var getAccessibilityState = memoize(getAccessibilityStateWorker);
function getAccessibilityStateWorker(disabled, accessibilityState) {
    if (accessibilityState) {
        return __assign({ disabled: disabled }, accessibilityState);
    }
    return { disabled: disabled };
}
export var useHoverFocusEffect = function (hovered, componentRef) {
    React.useLayoutEffect(function () {
        var _a, _b;
        if (hovered) {
            (_a = componentRef === null || componentRef === void 0 ? void 0 : componentRef.current) === null || _a === void 0 ? void 0 : _a.focus();
        }
        else {
            (_b = componentRef === null || componentRef === void 0 ? void 0 : componentRef.current) === null || _b === void 0 ? void 0 : _b.blur();
        }
    }, [hovered, componentRef]);
};
//# sourceMappingURL=useMenuItem.js.map