import { __assign, __rest, __spreadArray } from "tslib";
import * as React from 'react';
import { I18nManager, Platform } from 'react-native';
import { memoize } from '@fluentui-react-native/framework';
import { usePressableState, useKeyDownProps, useOnPressWithFocus, useViewCommandFocus } from '@fluentui-react-native/interactive-hooks';
import { useMenuContext } from '../context/menuContext';
import { useMenuListContext } from '../context/menuListContext';
import { submenuTriggerKeys, triggerKeys, useHoverFocusEffect } from '../MenuItem/useMenuItem';
import { useMenuItemTracking } from '../MenuList/useMenuList';
var defaultAccessibilityActions = [{ name: 'Toggle' }];
export var useMenuItemCheckbox = function (props) {
    var _a;
    var _b = props.disabled, disabled = _b === void 0 ? false : _b, name = props.name;
    var context = useMenuListContext();
    var checked = (_a = context.checked) === null || _a === void 0 ? void 0 : _a[name];
    var onCheckedChange = context.onCheckedChange;
    var toggleChecked = React.useCallback(function (e) {
        if (!disabled) {
            onCheckedChange(e, name, !checked);
        }
    }, [checked, disabled, name, onCheckedChange]);
    return useMenuCheckboxInteraction(props, toggleChecked);
};
var getAccessibilityState = memoize(getAccessibilityStateWorker);
function getAccessibilityStateWorker(disabled, checked, accessibilityState) {
    if (accessibilityState) {
        return __assign({ disabled: disabled, checked: checked }, accessibilityState);
    }
    return { disabled: disabled, checked: checked };
}
/**
 * Create interactivity and accessibility props to be passed into the inner render.
 * This logic is shared between Checkbox and Radio versions of MenuItem.
 *
 * @param props Props passed into the outer compoennt
 * @param toggleCallback Function to be called when item is toggled
 * @returns Props and additional state needed to render the component
 */
export var useMenuCheckboxInteraction = function (props, toggleCallback) {
    var defaultComponentRef = React.useRef(null);
    var accessibilityActions = props.accessibilityActions, accessibilityLabel = props.accessibilityLabel, accessibilityState = props.accessibilityState, accessible = props.accessible, _a = props.componentRef, componentRef = _a === void 0 ? defaultComponentRef : _a, _b = props.disabled, disabled = _b === void 0 ? false : _b, name = props.name, onAccessibilityAction = props.onAccessibilityAction, rest = __rest(props, ["accessibilityActions", "accessibilityLabel", "accessibilityState", "accessible", "componentRef", "disabled", "name", "onAccessibilityAction"]);
    var isSubmenu = useMenuContext().isSubmenu;
    var _c = useMenuListContext(), checked = _c.checked, hasIcons = _c.hasIcons, hasTooltips = _c.hasTooltips, onArrowClose = _c.onArrowClose;
    var isChecked = checked === null || checked === void 0 ? void 0 : checked[name];
    // Ensure focus is placed on checkbox after click
    var toggleCheckedWithFocus = useOnPressWithFocus(componentRef, toggleCallback);
    var pressable = usePressableState(__assign(__assign({}, rest), { onPress: toggleCheckedWithFocus }));
    var buttonRef = useViewCommandFocus(componentRef);
    var onKeysPressed = React.useCallback(function (e) {
        var invokeKey = e.nativeEvent.key === ' ' || e.nativeEvent.key === 'Enter';
        if (!disabled && invokeKey) {
            toggleCallback(e);
            return;
        }
        var isRtl = I18nManager.isRTL;
        var isArrowClose = isSubmenu && ((isRtl && e.nativeEvent.key === 'ArrowRight') || (!isRtl && e.nativeEvent.key === 'ArrowLeft'));
        if (isArrowClose) {
            onArrowClose === null || onArrowClose === void 0 ? void 0 : onArrowClose(e);
        }
    }, [disabled, isSubmenu, onArrowClose, toggleCallback]);
    var keys = disabled ? [] : isSubmenu ? submenuTriggerKeys : triggerKeys;
    var onKeyProps = useKeyDownProps.apply(void 0, __spreadArray([onKeysPressed], keys, false));
    var accessibilityActionsProp = accessibilityActions
        ? __spreadArray(__spreadArray([], defaultAccessibilityActions, true), accessibilityActions, true) : defaultAccessibilityActions;
    var onAccessibilityActionProp = React.useCallback(function (event) {
        if (!disabled) {
            if (event.nativeEvent.actionName === 'Toggle') {
                toggleCallback(event);
            }
            onAccessibilityAction && onAccessibilityAction(event);
        }
    }, [disabled, toggleCallback, onAccessibilityAction]);
    useHoverFocusEffect(pressable.state.hovered, componentRef);
    var _d = React.useState(!pressable.state.hovered), enableFocusRing = _d[0], setEnableFocusRing = _d[1];
    var onHoverIn = React.useCallback(function (e) {
        pressable.props.onHoverIn(e);
        // when it's a hover focus, set enableFocusRing explicitly to false
        if (!pressable.state.focused) {
            setEnableFocusRing(false);
        }
    }, [pressable]);
    var onFocus = React.useCallback(function (e) {
        pressable.props.onFocus(e);
        // when it's not a hover focus, set enableFocusRing explicitly to true
        if (!pressable.state.focused) {
            setEnableFocusRing(true);
        }
    }, [pressable]);
    // Track the ref and disabled props on this menu item so the MenuList can handle Home and End keypresses.
    useMenuItemTracking(componentRef, disabled);
    var state = __assign(__assign({}, pressable.state), { checked: isChecked, disabled: disabled, hasIcons: hasIcons, hasTooltips: hasTooltips });
    return {
        props: __assign(__assign(__assign({}, pressable.props), { onHoverIn: Platform.select({
                macos: pressable.props.onHoverIn,
                default: onHoverIn, // win32
            }), onFocus: Platform.select({
                macos: pressable.props.onFocus,
                default: onFocus, // win32
            }), accessible: accessible !== null && accessible !== void 0 ? accessible : true, accessibilityActions: accessibilityActionsProp, accessibilityLabel: accessibilityLabel, accessibilityRole: 'menuitem', accessibilityState: getAccessibilityState(disabled, state.checked, accessibilityState), disabled: disabled, enableFocusRing: Platform.select({
                macos: false,
                default: enableFocusRing, // win32
            }), focusable: Platform.select({
                macos: !disabled,
                default: true, // win32
            }), onAccessibilityAction: onAccessibilityActionProp, ref: buttonRef }), onKeyProps),
        state: state,
    };
};
//# sourceMappingURL=useMenuItemCheckbox.js.map