import { __assign, __rest } from "tslib";
/** @jsxRuntime classic */
/** @jsx withSlots */
import React from 'react';
import { Platform, ScrollView, View } from 'react-native';
import { FocusZone } from '@fluentui-react-native/focus-zone';
import { compose, mergeProps, stagedComponent, withSlots } from '@fluentui-react-native/framework';
import { stylingSettings } from './MenuList.styling';
import { menuListName } from './MenuList.types';
import { useMenuList } from './useMenuList';
import { useMenuListContextValue } from './useMenuListContextValue';
import { MenuListProvider } from '../context/menuListContext';
var MenuStack = stagedComponent(function (props) {
    var gap = props.gap, rest = __rest(props, ["gap"]);
    return function (final, children) {
        if (gap && gap > 0 && children) {
            // eslint-disable-next-line @typescript-eslint/ban-ts-comment
            // @ts-ignore - GH:1684, fix typing error
            children = React.Children.map(children, function (child, index) {
                if (React.isValidElement(child) && index > 0) {
                    return React.cloneElement(child, mergeProps(child.props, { style: { marginTop: gap } }));
                }
                return child;
            });
        }
        return withSlots(View, __assign({}, mergeProps(rest, final)), children);
    };
});
MenuStack.displayName = 'MenuStack';
var shouldHaveFocusZone = ['macos', 'win32'].includes(Platform.OS);
var focusLandsOnContainer = Platform.OS === 'macos';
var hasCircularNavigation = Platform.OS === 'win32';
export var menuListLookup = function (layer, state, userProps) {
    return state[layer] || userProps[layer] || layer === 'hasMaxHeight';
};
export var MenuList = compose(__assign(__assign({ displayName: menuListName }, stylingSettings), { slots: {
        root: MenuStack,
        scrollView: ScrollView,
        focusZone: shouldHaveFocusZone ? FocusZone : React.Fragment,
    }, useRender: function (userProps, useSlots) {
        var menuList = useMenuList(userProps);
        var menuListContextValue = useMenuListContextValue(menuList);
        var Slots = useSlots(menuList.props, function (layer) { return menuListLookup(layer, menuList, userProps); });
        return function (_final, children) {
            var itemCount = React.Children.toArray(children).filter(function (child) { return React.isValidElement(child) && child.type.displayName !== 'MenuDivider'; }).length;
            var itemPosition = 0;
            var childrenWithSet = React.Children.toArray(children).map(function (child) {
                var _a, _b;
                if (React.isValidElement(child)) {
                    if (child.type.displayName !== 'MenuDivider') {
                        itemPosition++;
                    }
                    return React.cloneElement(child, __assign({ accessibilityPositionInSet: (_a = child.props.accessibilityPositionInSet) !== null && _a !== void 0 ? _a : itemPosition, accessibilitySetSize: (_b = child.props.accessibilitySetSize) !== null && _b !== void 0 ? _b : itemCount }, (child.props.tooltip && { alwaysShowToolTip: true })));
                }
                return child;
            });
            var shouldHaveScrollView = Platform.OS === 'macos' || menuList.hasMaxHeight || menuList.hasMaxWidth;
            var ScrollViewWrapper = shouldHaveScrollView ? Slots.scrollView : React.Fragment;
            var hasMenuGroupChild = React.Children.toArray(children).some(function (child) { return child && child.type && child.type.displayName === 'MenuGroup'; });
            // On win32, tab navigation should only be enabled when we have menu groups.
            var hasTabNavigation = Platform.OS === 'win32' && hasMenuGroupChild;
            var content = (withSlots(Slots.root, null,
                withSlots(ScrollViewWrapper
                // avoid error that fires when props are passed into React.fragment
                , __assign({}, (shouldHaveScrollView && {
                    showsVerticalScrollIndicator: menuList.hasMaxHeight,
                    showsHorizontalScrollIndicator: menuList.hasMaxWidth,
                })),
                    withSlots(Slots.focusZone
                    // avoid error that fires when props are passed into React.fragment
                    , __assign({}, (shouldHaveFocusZone && {
                        componentRef: focusLandsOnContainer && menuList.focusZoneRef,
                        focusZoneDirection: 'vertical',
                        defaultTabbableElement: focusLandsOnContainer && menuList.focusZoneRef,
                        enableFocusRing: false,
                        isCircularNavigation: hasCircularNavigation,
                        tabKeyNavigation: hasTabNavigation ? 'Normal' : 'None',
                    })), childrenWithSet))));
            return withSlots(MenuListProvider, { value: menuListContextValue }, content);
        };
    } }));
//# sourceMappingURL=MenuList.js.map