import { __assign, __spreadArray } from "tslib";
import React from 'react';
import { Platform } from 'react-native';
import { useMergedRefs } from './useMergeRefs';
import { hoverDelayDefault } from '../consts';
import { useMenuContext } from '../context/menuContext';
var baseAccessibilityActions = Platform.OS === 'win32' ? [{ name: 'Expand' }, { name: 'Collapse' }] : [];
var expandedState = { expanded: true };
var collapsedState = { expanded: false };
export var useMenuTrigger = function (childProps) {
    var context = useMenuContext();
    var _a = context.hoverDelay, hoverDelay = _a === void 0 ? hoverDelayDefault : _a, open = context.open, openOnHover = context.openOnHover, popoverHoverOutTimer = context.popoverHoverOutTimer, setOpen = context.setOpen, setTriggerHoverOutTimer = context.setTriggerHoverOutTimer, triggerHoverOutTimer = context.triggerHoverOutTimer, triggerRef = context.triggerRef;
    var childAccessibilityActions = childProps.accessibilityActions, childAccessibilityState = childProps.accessibilityState, childOnAccessibilityAction = childProps.onAccessibilityAction, childAccessibilityPositionInSet = childProps.accessibilityPositionInSet, // win32
    childAccessibilitySetSize = childProps.accessibilitySetSize, // win32
    childOnClick = childProps.onClick, childOnHoverIn = childProps.onHoverIn, childOnHoverOut = childProps.onHoverOut, childComponentRef = childProps.componentRef;
    var accessibilityActions = React.useMemo(function () {
        if (childAccessibilityActions) {
            return __spreadArray(__spreadArray([], baseAccessibilityActions, true), childAccessibilityActions, true);
        }
        return baseAccessibilityActions;
    }, [childAccessibilityActions]);
    var accessibilityState = React.useMemo(function () {
        var baseState = open ? expandedState : collapsedState;
        if (childAccessibilityState) {
            return __assign(__assign({}, baseState), childAccessibilityState);
        }
        return baseState;
    }, [childAccessibilityState, open]);
    var onAccessibilityAction = React.useCallback(function (e) {
        if (Platform.OS === 'win32') {
            switch (e.nativeEvent.actionName) {
                case 'Expand':
                    setOpen(e, true /* isOpen */);
                    break;
                case 'Collapse':
                    setOpen(e, false /* isOpen */);
                    break;
            }
        }
        childOnAccessibilityAction && childOnAccessibilityAction(e);
    }, [childOnAccessibilityAction, setOpen]);
    var onHoverIn = React.useCallback(function (e) {
        if (openOnHover) {
            clearTimeout(popoverHoverOutTimer);
            clearTimeout(triggerHoverOutTimer);
            e.persist();
            setTimeout(function () {
                setOpen(e, true /* isOpen */);
            }, hoverDelay);
        }
        childOnHoverIn && childOnHoverIn(e);
    }, [childOnHoverIn, hoverDelay, openOnHover, setOpen, triggerHoverOutTimer, popoverHoverOutTimer]);
    var onHoverOut = React.useCallback(function (e) {
        if (openOnHover) {
            e.persist();
            var timer = setTimeout(function () {
                setOpen(e, false /* isOpen */);
            }, hoverDelay);
            setTriggerHoverOutTimer(timer);
        }
        childOnHoverOut && childOnHoverOut(e);
    }, [childOnHoverOut, hoverDelay, openOnHover, setOpen, setTriggerHoverOutTimer]);
    var onClick = React.useCallback(function (e) {
        setOpen(e, !open);
        childOnClick && childOnClick(e);
    }, [childOnClick, open, setOpen]);
    var ref = useMergedRefs(triggerRef, childComponentRef);
    return {
        props: {
            onClick: onClick,
            onHoverIn: onHoverIn,
            onHoverOut: onHoverOut,
            componentRef: ref,
            accessibilityState: accessibilityState,
            accessibilityActions: accessibilityActions,
            onAccessibilityAction: onAccessibilityAction,
            accessibilityPositionInSet: childAccessibilityPositionInSet !== null && childAccessibilityPositionInSet !== void 0 ? childAccessibilityPositionInSet : context.accessibilityPositionInSet,
            accessibilitySetSize: childAccessibilitySetSize !== null && childAccessibilitySetSize !== void 0 ? childAccessibilitySetSize : context.accessibilitySetSize, // win32
        },
        hasSubmenu: context.isSubmenu,
    };
};
//# sourceMappingURL=useMenuTrigger.js.map