import * as React from 'react';
import { ButtonV1 as Button } from '@fluentui-react-native/button';
import * as renderer from 'react-test-renderer';
import { Menu } from '../Menu/Menu';
import { MenuDivider } from '../MenuDivider/MenuDivider';
import { MenuGroup } from '../MenuGroup';
import { MenuGroupHeader } from '../MenuGroupHeader';
import { MenuItem } from '../MenuItem/MenuItem';
import { MenuItemCheckbox } from '../MenuItemCheckbox/MenuItemCheckbox';
import { MenuItemRadio } from '../MenuItemRadio/MenuItemRadio';
import { MenuList } from '../MenuList/MenuList';
import MenuPopover from '../MenuPopover/MenuPopover';
import MenuTrigger from '../MenuTrigger/MenuTrigger';
describe('Menu component tests', function () {
    it('Menu default', function () {
        var tree = renderer
            .create(React.createElement(Menu, null,
            React.createElement(MenuTrigger, null,
                React.createElement(Button, null, "Default")),
            React.createElement(MenuPopover, null,
                React.createElement(MenuList, null,
                    React.createElement(MenuItem, null, "Option 1")))))
            .toJSON();
        expect(tree).toMatchSnapshot();
    });
    it('Menu open', function () {
        var tree = renderer
            .create(React.createElement(Menu, { open: true },
            React.createElement(MenuTrigger, null,
                React.createElement(Button, null, "Open")),
            React.createElement(MenuPopover, null,
                React.createElement(MenuList, null,
                    React.createElement(MenuItem, null, "Option 1")))))
            .toJSON();
        expect(tree).toMatchSnapshot();
    });
    it('Menu defaultOpen', function () {
        var tree = renderer
            .create(React.createElement(Menu, { defaultOpen: true },
            React.createElement(MenuTrigger, null,
                React.createElement(Button, null, "Open")),
            React.createElement(MenuPopover, null,
                React.createElement(MenuList, null,
                    React.createElement(MenuItem, null, "Option 1"),
                    React.createElement(MenuItem, { disabled: true }, "Option 2")))))
            .toJSON();
        expect(tree).toMatchSnapshot();
    });
    it('Menu open checkbox and divider', function () {
        var tree = renderer
            .create(React.createElement(Menu, { open: true },
            React.createElement(MenuTrigger, null,
                React.createElement(Button, null, "Open")),
            React.createElement(MenuPopover, null,
                React.createElement(MenuList, null,
                    React.createElement(MenuItemCheckbox, { name: "Option 1" }, "Option 1"),
                    React.createElement(MenuDivider, null),
                    React.createElement(MenuItemCheckbox, { disabled: true, name: "Option 2" }, "Option 2")))))
            .toJSON();
        expect(tree).toMatchSnapshot();
    });
    it('Menu open radio', function () {
        var tree = renderer
            .create(React.createElement(Menu, { open: true },
            React.createElement(MenuTrigger, null,
                React.createElement(Button, null, "Open")),
            React.createElement(MenuPopover, null,
                React.createElement(MenuList, null,
                    React.createElement(MenuItemRadio, { name: "Option 1" }, "Option 1"),
                    React.createElement(MenuItemRadio, { name: "Option 2" }, "Option 2")))))
            .toJSON();
        expect(tree).toMatchSnapshot();
    });
    it('Menu open checkbox defaultChecked', function () {
        var tree = renderer
            .create(React.createElement(Menu, { open: true, defaultChecked: ['Option 1'] },
            React.createElement(MenuTrigger, null,
                React.createElement(Button, null, "Open")),
            React.createElement(MenuPopover, null,
                React.createElement(MenuList, null,
                    React.createElement(MenuItemCheckbox, { name: "Option 1" }, "Option 1"),
                    React.createElement(MenuDivider, null),
                    React.createElement(MenuItemCheckbox, { name: "Option 2" }, "Option 2")))))
            .toJSON();
        expect(tree).toMatchSnapshot();
    });
    it('Menu open checkbox checked', function () {
        var tree = renderer
            .create(React.createElement(Menu, { open: true, checked: ['Option 1'] },
            React.createElement(MenuTrigger, null,
                React.createElement(Button, null, "Open")),
            React.createElement(MenuPopover, null,
                React.createElement(MenuList, null,
                    React.createElement(MenuItemCheckbox, { name: "Option 1" }, "Option 1"),
                    React.createElement(MenuDivider, null),
                    React.createElement(MenuItemCheckbox, { name: "Option 2" }, "Option 2")))))
            .toJSON();
        expect(tree).toMatchSnapshot();
    });
    it('Menu submenu', function () {
        var tree = renderer
            .create(React.createElement(Menu, { open: true },
            React.createElement(MenuTrigger, null,
                React.createElement(Button, null, "Default")),
            React.createElement(MenuPopover, null,
                React.createElement(MenuList, null,
                    React.createElement(MenuItem, null, "Option 1"),
                    React.createElement(Menu, null,
                        React.createElement(MenuTrigger, null,
                            React.createElement(MenuItem, null, "Option 2")),
                        React.createElement(MenuPopover, null,
                            React.createElement(MenuList, null,
                                React.createElement(MenuItem, null, "Option 1"))))))))
            .toJSON();
        expect(tree).toMatchSnapshot();
    });
    // Note the capital T the "Tip" (in the snapshot)
    // It is intentional as it matches the same prop in NetUI
    it('Menu alwaysShowToolTip', function () {
        var tree = renderer
            .create(React.createElement(Menu, null,
            React.createElement(MenuTrigger, null,
                React.createElement(Button, { tooltip: "A Tooltip" }, "Button")),
            React.createElement(MenuPopover, null,
                React.createElement(MenuList, null,
                    React.createElement(MenuItem, null, "Test"),
                    React.createElement(MenuItem, { tooltip: "Second" }, "With Tooltip"),
                    React.createElement(MenuItemRadio, { name: "Radio", tooltip: "Third" }, "Radio Tooltip"),
                    React.createElement(MenuItemCheckbox, { name: "Check", tooltip: "Fourth" }, "Checkbox Tooltip")))))
            .toJSON();
        expect(tree).toMatchSnapshot();
    });
});
it('Menu open menu group and menu header', function () {
    var tree = renderer
        .create(React.createElement(Menu, { open: true },
        React.createElement(MenuTrigger, null,
            React.createElement(Button, null, "Open")),
        React.createElement(MenuPopover, null,
            React.createElement(MenuList, null,
                React.createElement(MenuGroup, null,
                    React.createElement(MenuGroupHeader, null, "Header 1"),
                    React.createElement(MenuItem, null, "Option 1")),
                React.createElement(MenuDivider, null),
                React.createElement(MenuGroup, null,
                    React.createElement(MenuGroupHeader, null, "Header 2"),
                    React.createElement(MenuItem, null, "Option 1"))))))
        .toJSON();
    expect(tree).toMatchSnapshot();
});
//# sourceMappingURL=Menu.test.js.map